==> tencentcloud-sdk-java-3.1.210-sources.jar: com/tencentcloudapi/ims/v20200713/models/Filters.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.ims.v20200713.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class Filters extends AbstractModel{

    /**
    * 查询字段：
策略BizType
子账号SubUin
日期区间DateRange
    */
    @SerializedName("Name")
    @Expose
    private String Name;

    /**
    * 查询值
    */
    @SerializedName("Values")
    @Expose
    private String [] Values;

    /**
     * Get 查询字段：
策略BizType
子账号SubUin
日期区间DateRange 
     * @return Name 查询字段：
策略BizType
子账号SubUin
日期区间DateRange
     */
    public String getName() {
        return this.Name;
    }

    /**
     * Set 查询字段：
策略BizType
子账号SubUin
日期区间DateRange
     * @param Name 查询字段：
策略BizType
子账号SubUin
日期区间DateRange
     */
    public void setName(String Name) {
        this.Name = Name;
    }

    /**
     * Get 查询值 
     * @return Values 查询值
     */
    public String [] getValues() {
        return this.Values;
    }

    /**
     * Set 查询值
     * @param Values 查询值
     */
    public void setValues(String [] Values) {
        this.Values = Values;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Name", this.Name);
        this.setParamArraySimple(map, prefix + "Values.", this.Values);

    }
}

==> tencentcloud-sdk-java-3.1.607-sources.jar: com/tencentcloudapi/ims/v20200713/models/Filters.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.ims.v20200713.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class Filters extends AbstractModel{

    /**
    * 查询字段：
策略BizType
子账号SubUin
日期区间DateRange
    */
    @SerializedName("Name")
    @Expose
    private String Name;

    /**
    * 查询值
    */
    @SerializedName("Values")
    @Expose
    private String [] Values;

    /**
     * Get 查询字段：
策略BizType
子账号SubUin
日期区间DateRange 
     * @return Name 查询字段：
策略BizType
子账号SubUin
日期区间DateRange
     */
    public String getName() {
        return this.Name;
    }

    /**
     * Set 查询字段：
策略BizType
子账号SubUin
日期区间DateRange
     * @param Name 查询字段：
策略BizType
子账号SubUin
日期区间DateRange
     */
    public void setName(String Name) {
        this.Name = Name;
    }

    /**
     * Get 查询值 
     * @return Values 查询值
     */
    public String [] getValues() {
        return this.Values;
    }

    /**
     * Set 查询值
     * @param Values 查询值
     */
    public void setValues(String [] Values) {
        this.Values = Values;
    }

    public Filters() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public Filters(Filters source) {
        if (source.Name != null) {
            this.Name = new String(source.Name);
        }
        if (source.Values != null) {
            this.Values = new String[source.Values.length];
            for (int i = 0; i < source.Values.length; i++) {
                this.Values[i] = new String(source.Values[i]);
            }
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Name", this.Name);
        this.setParamArraySimple(map, prefix + "Values.", this.Values);

    }
}
